#include "common/restext.h"

bool GetResource(ResType /* type */, int /* num */, std::string& /* text */)
{
    return true;
}

bool SearchKey(const char * /* cmd */, InputSlot & /* key */)
{
    return true;
}

